import _extends from "@babel/runtime/helpers/esm/extends";
import React, { useContext, useMemo } from 'react';
import classnames from 'classnames/bind';

function buildClassNameMapper(globalClassNameMap, localClassNameMap) {
  return classnames.bind(_extends({}, globalClassNameMap, {}, localClassNameMap));
}

var ClassNameContext = React.createContext({
  createClassNameMapper: function createClassNameMapper(localClassNameMap) {
    return buildClassNameMapper({}, localClassNameMap);
  }
});
var Consumer = ClassNameContext.Consumer,
    Provider = ClassNameContext.Provider;

function ClassNameProvider(_ref) {
  var classNameMap = _ref.classNameMap,
      children = _ref.children;
  var globalClassNameMap = useMemo(function () {
    return _extends({}, classNameMap);
  }, [classNameMap]);

  var createClassNameMapper = function createClassNameMapper(localClassNameMap) {
    return buildClassNameMapper(globalClassNameMap, localClassNameMap);
  };

  return React.createElement(Provider, {
    value: {
      createClassNameMapper: createClassNameMapper
    }
  }, children);
}

export function useClassNameMapper(localClassNameMap) {
  var _useContext = useContext(ClassNameContext),
      createClassNameMapper = _useContext.createClassNameMapper;

  return createClassNameMapper(localClassNameMap);
}
export { Consumer as ClassNameConsumer, ClassNameContext };
export default ClassNameProvider;